/*
  Creates the users table with the _id and name fields.
*/
CREATE TABLE IF NOT EXISTS users (
    [_id] INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
    [name] TEXT NOT NULL
);
/*
  Inserts the default user to the users table.
*/
INSERT INTO users(name) VALUES ("%default_user_name%");
/*
   Creates the delete trigger to prohibit deleting last user.
*/
CREATE TRIGGER prohibit_last_user_deleting BEFORE DELETE ON users
BEGIN
SELECT RAISE(ABORT, 'deletion disabled') WHERE (SELECT count(*) FROM users) < 2; END;

/*
   Creates the preferences table with the name, value and user_id fields.
*/
CREATE TABLE IF NOT EXISTS preferences (
    [name] TEXT NOT NULL,
    [value] TEXT,
    [user_id] INTEGER NOT NULL REFERENCES users(_id) ON DELETE CASCADE,
    PRIMARY KEY (name, user_id)
);

/*
   Creates the reminders table with the _id, time, days, user_id and turned_on fields.
*/
CREATE TABLE IF NOT EXISTS reminders (
    [_id] INTEGER PRIMARY KEY AUTOINCREMENT,
    [time] TEXT NOT NULL,
    [days] TEXT NOT NULL,
    [user_id] INTEGER NOT NULL REFERENCES users(_id) ON DELETE CASCADE,
    [turned_on] INTEGER NOT NULL
);

ALTER TABLE blood_pressure_measurement
ADD COLUMN user_id INTEGER DEFAULT 1 REFERENCES users(_id) ON DELETE CASCADE;
