/* Renames the reminders table to temp_table. */
ALTER TABLE reminders RENAME TO temp_table;

/*
   Creates the new reminders table with the _id, time, days, user_id, timestamp, title, info,
   class, method, owner_id, start, end, external_id, dosync and del fields.
*/
CREATE TABLE IF NOT EXISTS reminders (
    [_id] INTEGER PRIMARY KEY AUTOINCREMENT,
    [time] TEXT NOT NULL,
    [days] TEXT NOT NULL,
    [user_id] INTEGER NOT NULL REFERENCES users(_id) ON DELETE CASCADE,
    [timestamp] TEXT NOT NULL,
    [title] TEXT,
    [info] TEXT,
    [class] TEXT NOT NULL,
    [method] TEXT,
    [owner_id] TEXT,
    [start] TEXT NOT NULL,
    [end] TEXT,
    [external_id] TEXT,
    [dosync] INTEGER NOT NULL DEFAULT 1,
    [del] INTEGER NOT NULL DEFAULT 0
);

/* Inserts records from temp_table to the new reminders table. */
INSERT INTO reminders (_id, time, days, user_id, timestamp, class, method, start)
    SELECT _id, time, days, user_id, "%current_datetime%", "bp", "app", "%current_datetime%"
    FROM temp_table;

/* Drops the temp_table table.*/
DROP TABLE temp_table;

/*
   Creates the new medications table with the _id, medication_name, medication_id,
   medication_count, medication_dsc, dose, event_id, event_at, event_time, event_result,
   user_id, timestamp, external_id, dosync and del fields.
*/
CREATE TABLE IF NOT EXISTS medications (
    [_id] INTEGER PRIMARY KEY AUTOINCREMENT,
    [medication_name] TEXT NOT NULL,
    [medication_id] TEXT,
    [medication_count] REAL,
    [medication_dsc] TEXT,
    [dose] REAL,
    [event_id] TEXT,
    [event_at] TEXT,
    [event_time] TEXT NOT NULL,
    [event_result] TEXT,
    [user_id] INTEGER NOT NULL REFERENCES users(_id) ON DELETE CASCADE,
    [timestamp] TEXT NOT NULL,
    [external_id] TEXT,
    [dosync] INTEGER NOT NULL DEFAULT 1,
    [del] INTEGER NOT NULL DEFAULT 0
);
